@@ -11,6 +11,7 @@ from .sics import *
 from .rics import *
 from .operators import *
 from .gpt import *
-from .optimize.quantumness import *
-from .optimize.meffs import *
-from .qplex import *
\ No newline at end of file
+from .optimize import *
+from .qplex import *
+from .spin import *
+from .grassmannian import *
\ No newline at end of file
