@@ -1,5 +1,7 @@
 import numpy as np
 from .utils import *
+import sympy
+import sympy.liealgebras.type_a
 
 def mercedes_benz_frame():
     return np.array([[r.real, r.imag] for r in [np.exp(2j*np.pi*i/3) for i in range(3)]]).T*np.sqrt(2/3)
@@ -48,5 +50,13 @@ def petersen_frame():
                                1/6) for b in petersen_vertices]\
                                         for a in petersen_vertices]) 
     U, D, V = np.linalg.svd(petersen_gram)
-    return V[:4].T @ np.sqrt(np.diag(D[:4]))*np.sqrt(4/10)
+    return (V[:4].T @ np.sqrt(np.diag(D[:4]))*np.sqrt(4/10)).T
 
+def honey_frame(d, full=False):
+    n = d*(d+1)/2
+    A = sympy.liealgebras.type_a.TypeA(d)
+    roots = [np.array(root) for root in A.positive_roots().values()]
+    if full:
+        roots.extend([-r for r in roots])
+    U, D, V = np.linalg.svd(np.array(roots).T)
+    return np.array([state/np.linalg.norm(state) for state in V[:d].T]).T*np.sqrt(d/n)
